@@ -24,7 +24,7 @@
 
 
 save_json <- function(annotations, file) {
-  if(!class(annotations) == 'gvision_annotations') {
+  if(!is(annotations, 'gvision_annotations')) {
     stop('this function only accepts annotation object')
   }
   # open file connection
